@@ -322,7 +322,7 @@ class Process(object):
                 replace = "distributed_tracing.enabled = false"
                 replace_with = "distributed_tracing.enabled = true"
 
-                if args.region.casefold() == "STAGING".casefold():
+                if args.region.upper() == "STAGING":
                     replace_with += "\n\nhost = staging-collector.newrelic.com"
 
                 dt_replaced_text = file_text.replace(replace, replace_with)
@@ -332,7 +332,6 @@ class Process(object):
 
                 file.write(final_config)
 
-
     def install(self, args):
         install_command = self.rewrite_install_command()
 
@@ -384,7 +383,8 @@ class Process(object):
 
 def list_instrumentable_pids(args):
     process_tree = ProcessTree()
-    pids = [pid for pid, process in process_tree.items() if process.is_instrumentable]
+    pids = [pid for pid, process in process_tree.items()
+            if process.is_instrumentable]
 
     print(json.dumps(pids))
 
@@ -558,7 +558,7 @@ def main():
         "--region",
         choices=['US', 'EU', 'STAGING'],
         help="the region to report into",
-        default=os.environ.get('NEW_RELIC_REGION', "PROD"),
+        default=os.environ.get('NEW_RELIC_REGION', "US"),
         dest="region",
     )
 
